aboutsummaryrefslogtreecommitdiff
path: root/engines/gob/inter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/gob/inter.cpp')
-rw-r--r--engines/gob/inter.cpp8
1 files changed, 5 insertions, 3 deletions
diff --git a/engines/gob/inter.cpp b/engines/gob/inter.cpp
index 869ab958c7..cd9685db2e 100644
--- a/engines/gob/inter.cpp
+++ b/engines/gob/inter.cpp
@@ -231,10 +231,12 @@ void Inter::funcBlock(int16 retFlag) {
break;
// WORKAROUND:
// The EGA and Mac versions of gob1 doesn't add a delay after showing
// images between levels. We manually add it here.
if ((_vm->getGameType() == kGameTypeGob1) &&
- (_vm->isEGA() || (_vm->getPlatform() == Common::kPlatformMacintosh))) {
+ ( _vm->isEGA() ||
+ (_vm->getPlatform() == Common::kPlatformMacintosh) ||
+ (_vm->getPlatform() == Common::kPlatformWindows))) {
int addr = _vm->_global->_inter_execPtr-_vm->_game->_totFileData;
@@ -231,10 +231,12 @@ void Inter::funcBlock(int16 retFlag) {
break;
// WORKAROUND:
- // The EGA and Mac versions of gob1 doesn't add a delay after showing
- // images between levels. We manually add it here.
+ // The EGA, Mac and Windows versions of gob1 doesn't add a delay after
+ // showing images between levels. We manually add it here.
if ((_vm->getGameType() == kGameTypeGob1) &&